Documentation
¶
Index ¶
Constants ¶
const ( CreepSnowblower = iota + 1 CreepSmallRock CreepMediumRock CreepLargeRock )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CreepBullet ¶
type CreepBullet struct {
Invulnerable bool // Invulnerable to hazards
}
type PlayerBullet ¶
type PlayerBullet struct {
}
type Rail ¶
type Rail struct {
}
Rail is a component added to all entities which should move along the rail with the camera.
type Sprite ¶
type Sprite struct {
Image *ebiten.Image
HorizontalFlip bool
VerticalFlip bool
Angle float64
Overlay *ebiten.Image
OverlayX, OverlayY float64 // Overlay offset
Frame int
Frames []*ebiten.Image
FrameTime time.Duration
LastFrame time.Time
NumFrames int
DamageTicks int
OverrideColorScale bool
ColorScale float64
OffsetX, OffsetY float64
Images []*ebiten.Image
}
Click to show internal directories.
Click to hide internal directories.